;; Generated package description from devdocs.el  -*- no-byte-compile: t -*-
(define-package "devdocs" "0.6.0.20240323.82337" "Emacs viewer for DevDocs" '((emacs "27.1")) :commit "01ce2c06e997cb821be6123395fb6d224bf958ab" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("help") :url "https://github.com/astoff/devdocs.el")
